==> ros-nodelet-core_1.9.3.orig.tar.gz: ros-nodelet-core-1.9.3/test_nodelet/src/create_instance_cb_error.cpp <==
/*
 * Copyright (c) 2011, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

// Helper for issue #23: nodelet loader hides load error
// should generate a helpful error message containing "NODELET_TEST_FAILURE"

#include <nodelet/loader.h>
#include <ros/init.h>

#include <boost/bind.hpp>

boost::shared_ptr<nodelet::Nodelet> create_instance(const std::string& lookup_name)
{
    throw std::runtime_error("NODELET_TEST_FAILURE");
}

int main(int argc, char** argv)
{
    ros::init(argc, argv, "simple_loader");

    nodelet::Loader loader(boost::bind(&create_instance, _1));
    std::map<std::string, std::string> remappings;
    std::vector<std::string> my_argv;
    if(!loader.load("/fail", "test_nodelet/FailingNodelet", remappings, my_argv))
        return 1;

    return 0;
}

==> ros-nodelet-core_1.9.16.orig.tar.gz: ros-nodelet-core-1.9.16/test_nodelet/src/create_instance_cb_error.cpp <==
/*
 * Copyright (c) 2011, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

// Helper for issue #23: nodelet loader hides load error
// should generate a helpful error message containing "NODELET_TEST_FAILURE"

#include <nodelet/loader.h>
#include <ros/init.h>

#include <boost/bind.hpp>

boost::shared_ptr<nodelet::Nodelet> create_instance(const std::string&)
{
    throw std::runtime_error("NODELET_TEST_FAILURE");
}

int main(int argc, char** argv)
{
    ros::init(argc, argv, "simple_loader");

    nodelet::Loader loader(boost::bind(&create_instance, _1));
    std::map<std::string, std::string> remappings;
    std::vector<std::string> my_argv;
    if(!loader.load("/fail", "test_nodelet/FailingNodelet", remappings, my_argv))
        return 1;

    return 0;
}
